@@ -19,19 +19,19 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 
 */
 // Self
-#include "saveallhelper.moc"
+#include "saveallhelper.h"
 
 // Qt
 #include <QFuture>
 #include <QFutureWatcher>
 #include <QSet>
 #include <QStringList>
+#include <QUrl>
+#include <QProgressDialog>
 
 // KDE
-#include <KLocale>
+#include <KLocalizedString>
 #include <KMessageBox>
-#include <KProgressDialog>
-#include <KUrl>
 
 // Local
 #include <lib/document/document.h>
@@ -44,7 +44,7 @@ namespace Gwenview
 struct SaveAllHelperPrivate
 {
     QWidget* mParent;
-    KProgressDialog* mProgressDialog;
+    QProgressDialog* mProgressDialog;
     QSet<DocumentJob*> mJobSet;
     QStringList mErrorList;
 };
@@ -53,11 +53,11 @@ SaveAllHelper::SaveAllHelper(QWidget* parent)
 : d(new SaveAllHelperPrivate)
 {
     d->mParent = parent;
-    d->mProgressDialog = new KProgressDialog(parent);
-    connect(d->mProgressDialog, SIGNAL(cancelClicked()), SLOT(slotCanceled()));
+    d->mProgressDialog = new QProgressDialog(parent);
+    connect(d->mProgressDialog, &QProgressDialog::canceled, this, &SaveAllHelper::slotCanceled);
     d->mProgressDialog->setLabelText(i18nc("@info:progress saving all image changes", "Saving..."));
-    d->mProgressDialog->setButtonText(i18n("&Stop"));
-    d->mProgressDialog->progressBar()->setMinimum(0);
+    d->mProgressDialog->setCancelButtonText(i18n("&Stop"));
+    d->mProgressDialog->setMinimum(0);
 }
 
 SaveAllHelper::~SaveAllHelper()
@@ -67,13 +67,13 @@ SaveAllHelper::~SaveAllHelper()
 
 void SaveAllHelper::save()
 {
-    KUrl::List list = DocumentFactory::instance()->modifiedDocumentList();
-    d->mProgressDialog->progressBar()->setRange(0, list.size());
-    d->mProgressDialog->progressBar()->setValue(0);
-    Q_FOREACH(const KUrl & url, list) {
+    QList<QUrl> list = DocumentFactory::instance()->modifiedDocumentList();
+    d->mProgressDialog->setRange(0, list.size());
+    d->mProgressDialog->setValue(0);
+    Q_FOREACH(const QUrl &url, list) {
         Document::Ptr doc = DocumentFactory::instance()->load(url);
         DocumentJob* job = doc->save(url, doc->format());
-        connect(job, SIGNAL(result(KJob*)), SLOT(slotResult(KJob*)));
+        connect(job, &DocumentJob::result, this, &SaveAllHelper::slotResult);
         d->mJobSet << job;
     }
 
@@ -102,14 +102,13 @@ void SaveAllHelper::slotResult(KJob* _job)
 {
     DocumentJob* job = static_cast<DocumentJob*>(_job);
     if (job->error()) {
-        KUrl url = job->document()->url();
-        QString name = url.fileName().isEmpty() ? url.pathOrUrl() : url.fileName();
-        d->mErrorList << i18nc("@info %1 is the name of the document which failed to save, %2 is the reason for the failure",
-                               "<filename>%1</filename>: %2", name, job->errorString());
+        QUrl url = job->document()->url();
+        QString name = url.fileName().isEmpty() ? url.toDisplayString() : url.fileName();
+        d->mErrorList << xi18nc("@info %1 is the name of the document which failed to save, %2 is the reason for the failure",
+                                "<filename>%1</filename>: %2", name, job->errorString());
     }
     d->mJobSet.remove(job);
-    QProgressBar* bar = d->mProgressDialog->progressBar();
-    bar->setValue(bar->value() + 1);
+    d->mProgressDialog->setValue(d->mProgressDialog->value() + 1);
 }
 
 } // namespace
